Warning! this package is still in develpment, excpect bugs and incomplete fueters.

This is a simple package for 3d rendering
in python. Documentation will be coming soon.

instalation: pip install TI3D

made by: Legolars2800